#!/usr/bin/perl -w
#########################################################################
#
# Serz Minus (Sergey Lepenkov), <abalama@cpan.org>
#
# Copyright (C) 1998-2020 D&D Corporation. All Rights Reserved
#
# This is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# $Id: 02-sysinfo.t 53 2020-04-09 23:03:57Z abalama $
#
#########################################################################
use Test::More tests => 16;
BEGIN { use_ok('VISD::SysInfo') };

use constant DEBUG => 0;

# Get version
{
    ok(VISD::SysInfo->VERSION, 'Version');
}

# SysInfo
{
    my %sysinfo = get_sysinfo();
    ok(keys(%sysinfo), 'Sysinfo') && _note(explain({%sysinfo}));
}

# proc/uptime
{
    my $ut = get_uptime();
    ok($ut, 'proc/uptime') && _note($ut);
}

# POSIX uname
{
    my %uname = get_uname();
    ok(keys(%uname), 'POSIX uname') && _note(explain({%uname}));
}

# proc/cpuinfo
{
    my %cpuinfo = get_cpuinfo();
    ok(keys(%cpuinfo), '/proc/cpuinfo') && _note(explain({%cpuinfo}));

}

# proc/stat
{
    my %stat = get_stat();
    ok(keys(%stat), '/proc/stat') && _note(explain({%stat}));
}

# proc/net/route
{
    my @route = get_net_route();
    ok(@route, '/proc/net/route') && _note(explain([@route]));

}

# proc/net/ipv6_route
{
    my @route = get_net_ipv6_route();
    ok(@route, '/proc/net/ipv6_route') && _note(explain([@route]));

}

# proc/net/dev
{
    my %dev = get_net_dev();
    ok(keys(%dev), '/proc/net/dev') && _note(explain({%dev}));
}

# Disk stats
{
    if (my %ds = get_diskstats()) {
        ok(keys(%ds), 'get_diskstats') && _note(explain({%ds}));
    } else {
        pass('get_diskstats');
    }
}

# BlockIO
{
    if (my %blkio = get_blkio()) {
        ok(keys(%blkio), 'get_blkio') && _note(explain({%blkio}));
    } else {
        pass('get_blkio');
    }
}

# proc/mounts
{
    my %mounts = get_mounts();
    ok(keys(%mounts), '/proc/mounts') && _note(explain({%mounts}));
}

# proc/filesystems
{
    my @fs = get_filesystems(0);
    ok(@fs, '/proc/filesystems') && _note(explain([@fs]));
}

# Disk free
{
    if (my %df = get_disk_free()) {
        ok(keys(%df), 'get_disk_free') && _note(explain({%df}));
    } else {
         pass('get_disk_free');
    }
}

# Df
{
    my %df = VISD::SysInfo::df("/");
    ok(keys(%df), 'df') && _note(explain({%df}));
}


sub _note {
    return 1 unless DEBUG;
    note(@_);
}

1;

__END__
